@@ -26,7 +26,7 @@
 
 #define GMT_PACKAGE_VERSION "6.6.0"
 #define GMT_PACKAGE_VERSION_WITH_GIT_REVISION "6.6.0"
-#define GMT_BUILD_DATE "2025.09.14"
+#define GMT_BUILD_DATE "2025.11.16"
 
 /* URL to the docs on the GMT web server */
 #define GMT_DOC_URL "https://docs.generic-mapping-tools.org/6.6"
@@ -46,11 +46,11 @@
 /* URL to remote files */
 #define GMT_DATA_SERVER "oceania"
 
-/* for running and debugging in /startdir/src/build */
+/* for running and debugging in /build/gmt/src/build */
 /* #undef SUPPORT_EXEC_IN_BINARY_DIR */
-#define GMT_SHARE_DIR_DEBUG "/startdir/src/gmt-6.6.0/share"
-#define GMT_USER_DIR_DEBUG "/startdir/src/build/share"
-#define GMT_BINARY_DIR_SRC_DEBUG "/startdir/src/build/src"
+#define GMT_SHARE_DIR_DEBUG "/build/gmt/src/gmt-6.6.0/share"
+#define GMT_USER_DIR_DEBUG "/build/gmt/src/build/share"
+#define GMT_BINARY_DIR_SRC_DEBUG "/build/gmt/src/build/src"
 
 /* path to documentation */
 #define GMT_DOC_DIR "/usr/share/doc/gmt"
